@@ -5,8 +5,8 @@ import sys
 import base64
 import binascii
 
-sys.path.append('../..')
-from core.Plugins.Decoder import *
+sys.path.append('../../..')
+from pcapfex.core.Plugins.Decoder import *
 
 
 def getClassReference():
