@@ -3,9 +3,9 @@ __author__ = 'Viktor Winkelmann'
 
 import sys
 
-sys.path.append('../..')
+sys.path.append('../../..')
 
-from plugins.protocol_dissectors.http11 import HTTP11
+from pcapfex.plugins.protocol_dissectors.http11 import HTTP11
 from io import BytesIO
 from contextlib import closing
 
